/*******************************************************************************
* File Name: OpampA_PM.c
* Version 1.90
*
* Description:
*  This file provides the power management source code to the API for the 
*  OpAmp (Analog Buffer) component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OpampA.h"

static OpampA_BACKUP_STRUCT  OpampA_backup;


/*******************************************************************************  
* Function Name: OpampA_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration registers.
* 
* Parameters:
*  void
* 
* Return:
*  void
*
*******************************************************************************/
void OpampA_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: OpampA_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration registers.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampA_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: OpampA_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampA_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void OpampA_Sleep(void) 
{
    /* Save OpAmp enable state */
    if((OpampA_PM_ACT_CFG_REG & OpampA_ACT_PWR_EN) != 0u)
    {
        /* Component is enabled */
        OpampA_backup.enableState = 1u;
         /* Stops the component */
         OpampA_Stop();
    }
    else
    {
        /* Component is disabled */
        OpampA_backup.enableState = 0u;
    }
    /* Saves the configuration */
    OpampA_SaveConfig();
}


/*******************************************************************************  
* Function Name: OpampA_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampA_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
*******************************************************************************/
void OpampA_Wakeup(void) 
{
    /* Restore the user configuration */
    OpampA_RestoreConfig();

    /* Enables the component operation */
    if(OpampA_backup.enableState == 1u)
    {
        OpampA_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
