/*******************************************************************************
* File Name: OpampB_PM.c
* Version 1.90
*
* Description:
*  This file provides the power management source code to the API for the 
*  OpAmp (Analog Buffer) component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OpampB.h"

static OpampB_BACKUP_STRUCT  OpampB_backup;


/*******************************************************************************  
* Function Name: OpampB_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration registers.
* 
* Parameters:
*  void
* 
* Return:
*  void
*
*******************************************************************************/
void OpampB_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: OpampB_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration registers.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampB_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: OpampB_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampB_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void OpampB_Sleep(void) 
{
    /* Save OpAmp enable state */
    if((OpampB_PM_ACT_CFG_REG & OpampB_ACT_PWR_EN) != 0u)
    {
        /* Component is enabled */
        OpampB_backup.enableState = 1u;
         /* Stops the component */
         OpampB_Stop();
    }
    else
    {
        /* Component is disabled */
        OpampB_backup.enableState = 0u;
    }
    /* Saves the configuration */
    OpampB_SaveConfig();
}


/*******************************************************************************  
* Function Name: OpampB_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampB_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
*******************************************************************************/
void OpampB_Wakeup(void) 
{
    /* Restore the user configuration */
    OpampB_RestoreConfig();

    /* Enables the component operation */
    if(OpampB_backup.enableState == 1u)
    {
        OpampB_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
