/*******************************************************************************
* File Name: outa.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_outa_H) /* Pins outa_H */
#define CY_PINS_outa_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "outa_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 outa__PORT == 15 && ((outa__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    outa_Write(uint8 value);
void    outa_SetDriveMode(uint8 mode);
uint8   outa_ReadDataReg(void);
uint8   outa_Read(void);
void    outa_SetInterruptMode(uint16 position, uint16 mode);
uint8   outa_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the outa_SetDriveMode() function.
     *  @{
     */
        #define outa_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define outa_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define outa_DM_RES_UP          PIN_DM_RES_UP
        #define outa_DM_RES_DWN         PIN_DM_RES_DWN
        #define outa_DM_OD_LO           PIN_DM_OD_LO
        #define outa_DM_OD_HI           PIN_DM_OD_HI
        #define outa_DM_STRONG          PIN_DM_STRONG
        #define outa_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define outa_MASK               outa__MASK
#define outa_SHIFT              outa__SHIFT
#define outa_WIDTH              1u

/* Interrupt constants */
#if defined(outa__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in outa_SetInterruptMode() function.
     *  @{
     */
        #define outa_INTR_NONE      (uint16)(0x0000u)
        #define outa_INTR_RISING    (uint16)(0x0001u)
        #define outa_INTR_FALLING   (uint16)(0x0002u)
        #define outa_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define outa_INTR_MASK      (0x01u) 
#endif /* (outa__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define outa_PS                     (* (reg8 *) outa__PS)
/* Data Register */
#define outa_DR                     (* (reg8 *) outa__DR)
/* Port Number */
#define outa_PRT_NUM                (* (reg8 *) outa__PRT) 
/* Connect to Analog Globals */                                                  
#define outa_AG                     (* (reg8 *) outa__AG)                       
/* Analog MUX bux enable */
#define outa_AMUX                   (* (reg8 *) outa__AMUX) 
/* Bidirectional Enable */                                                        
#define outa_BIE                    (* (reg8 *) outa__BIE)
/* Bit-mask for Aliased Register Access */
#define outa_BIT_MASK               (* (reg8 *) outa__BIT_MASK)
/* Bypass Enable */
#define outa_BYP                    (* (reg8 *) outa__BYP)
/* Port wide control signals */                                                   
#define outa_CTL                    (* (reg8 *) outa__CTL)
/* Drive Modes */
#define outa_DM0                    (* (reg8 *) outa__DM0) 
#define outa_DM1                    (* (reg8 *) outa__DM1)
#define outa_DM2                    (* (reg8 *) outa__DM2) 
/* Input Buffer Disable Override */
#define outa_INP_DIS                (* (reg8 *) outa__INP_DIS)
/* LCD Common or Segment Drive */
#define outa_LCD_COM_SEG            (* (reg8 *) outa__LCD_COM_SEG)
/* Enable Segment LCD */
#define outa_LCD_EN                 (* (reg8 *) outa__LCD_EN)
/* Slew Rate Control */
#define outa_SLW                    (* (reg8 *) outa__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define outa_PRTDSI__CAPS_SEL       (* (reg8 *) outa__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define outa_PRTDSI__DBL_SYNC_IN    (* (reg8 *) outa__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define outa_PRTDSI__OE_SEL0        (* (reg8 *) outa__PRTDSI__OE_SEL0) 
#define outa_PRTDSI__OE_SEL1        (* (reg8 *) outa__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define outa_PRTDSI__OUT_SEL0       (* (reg8 *) outa__PRTDSI__OUT_SEL0) 
#define outa_PRTDSI__OUT_SEL1       (* (reg8 *) outa__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define outa_PRTDSI__SYNC_OUT       (* (reg8 *) outa__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(outa__SIO_CFG)
    #define outa_SIO_HYST_EN        (* (reg8 *) outa__SIO_HYST_EN)
    #define outa_SIO_REG_HIFREQ     (* (reg8 *) outa__SIO_REG_HIFREQ)
    #define outa_SIO_CFG            (* (reg8 *) outa__SIO_CFG)
    #define outa_SIO_DIFF           (* (reg8 *) outa__SIO_DIFF)
#endif /* (outa__SIO_CFG) */

/* Interrupt Registers */
#if defined(outa__INTSTAT)
    #define outa_INTSTAT            (* (reg8 *) outa__INTSTAT)
    #define outa_SNAP               (* (reg8 *) outa__SNAP)
    
	#define outa_0_INTTYPE_REG 		(* (reg8 *) outa__0__INTTYPE)
#endif /* (outa__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_outa_H */


/* [] END OF FILE */
