/*******************************************************************************
* File Name: pwmout.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_pwmout_H) /* Pins pwmout_H */
#define CY_PINS_pwmout_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "pwmout_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 pwmout__PORT == 15 && ((pwmout__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    pwmout_Write(uint8 value);
void    pwmout_SetDriveMode(uint8 mode);
uint8   pwmout_ReadDataReg(void);
uint8   pwmout_Read(void);
void    pwmout_SetInterruptMode(uint16 position, uint16 mode);
uint8   pwmout_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the pwmout_SetDriveMode() function.
     *  @{
     */
        #define pwmout_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define pwmout_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define pwmout_DM_RES_UP          PIN_DM_RES_UP
        #define pwmout_DM_RES_DWN         PIN_DM_RES_DWN
        #define pwmout_DM_OD_LO           PIN_DM_OD_LO
        #define pwmout_DM_OD_HI           PIN_DM_OD_HI
        #define pwmout_DM_STRONG          PIN_DM_STRONG
        #define pwmout_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define pwmout_MASK               pwmout__MASK
#define pwmout_SHIFT              pwmout__SHIFT
#define pwmout_WIDTH              1u

/* Interrupt constants */
#if defined(pwmout__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in pwmout_SetInterruptMode() function.
     *  @{
     */
        #define pwmout_INTR_NONE      (uint16)(0x0000u)
        #define pwmout_INTR_RISING    (uint16)(0x0001u)
        #define pwmout_INTR_FALLING   (uint16)(0x0002u)
        #define pwmout_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define pwmout_INTR_MASK      (0x01u) 
#endif /* (pwmout__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define pwmout_PS                     (* (reg8 *) pwmout__PS)
/* Data Register */
#define pwmout_DR                     (* (reg8 *) pwmout__DR)
/* Port Number */
#define pwmout_PRT_NUM                (* (reg8 *) pwmout__PRT) 
/* Connect to Analog Globals */                                                  
#define pwmout_AG                     (* (reg8 *) pwmout__AG)                       
/* Analog MUX bux enable */
#define pwmout_AMUX                   (* (reg8 *) pwmout__AMUX) 
/* Bidirectional Enable */                                                        
#define pwmout_BIE                    (* (reg8 *) pwmout__BIE)
/* Bit-mask for Aliased Register Access */
#define pwmout_BIT_MASK               (* (reg8 *) pwmout__BIT_MASK)
/* Bypass Enable */
#define pwmout_BYP                    (* (reg8 *) pwmout__BYP)
/* Port wide control signals */                                                   
#define pwmout_CTL                    (* (reg8 *) pwmout__CTL)
/* Drive Modes */
#define pwmout_DM0                    (* (reg8 *) pwmout__DM0) 
#define pwmout_DM1                    (* (reg8 *) pwmout__DM1)
#define pwmout_DM2                    (* (reg8 *) pwmout__DM2) 
/* Input Buffer Disable Override */
#define pwmout_INP_DIS                (* (reg8 *) pwmout__INP_DIS)
/* LCD Common or Segment Drive */
#define pwmout_LCD_COM_SEG            (* (reg8 *) pwmout__LCD_COM_SEG)
/* Enable Segment LCD */
#define pwmout_LCD_EN                 (* (reg8 *) pwmout__LCD_EN)
/* Slew Rate Control */
#define pwmout_SLW                    (* (reg8 *) pwmout__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define pwmout_PRTDSI__CAPS_SEL       (* (reg8 *) pwmout__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define pwmout_PRTDSI__DBL_SYNC_IN    (* (reg8 *) pwmout__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define pwmout_PRTDSI__OE_SEL0        (* (reg8 *) pwmout__PRTDSI__OE_SEL0) 
#define pwmout_PRTDSI__OE_SEL1        (* (reg8 *) pwmout__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define pwmout_PRTDSI__OUT_SEL0       (* (reg8 *) pwmout__PRTDSI__OUT_SEL0) 
#define pwmout_PRTDSI__OUT_SEL1       (* (reg8 *) pwmout__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define pwmout_PRTDSI__SYNC_OUT       (* (reg8 *) pwmout__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(pwmout__SIO_CFG)
    #define pwmout_SIO_HYST_EN        (* (reg8 *) pwmout__SIO_HYST_EN)
    #define pwmout_SIO_REG_HIFREQ     (* (reg8 *) pwmout__SIO_REG_HIFREQ)
    #define pwmout_SIO_CFG            (* (reg8 *) pwmout__SIO_CFG)
    #define pwmout_SIO_DIFF           (* (reg8 *) pwmout__SIO_DIFF)
#endif /* (pwmout__SIO_CFG) */

/* Interrupt Registers */
#if defined(pwmout__INTSTAT)
    #define pwmout_INTSTAT            (* (reg8 *) pwmout__INTSTAT)
    #define pwmout_SNAP               (* (reg8 *) pwmout__SNAP)
    
	#define pwmout_0_INTTYPE_REG 		(* (reg8 *) pwmout__0__INTTYPE)
#endif /* (pwmout__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_pwmout_H */


/* [] END OF FILE */
